# exrio

Fast and dependency-free python library for reading and writing OpenEXR files.

## Development

### Install Tools

- [Rust](https://www.rust-lang.org/tools/install)
- [Python](https://www.python.org/downloads/)
- [maturin](https://maturin.rs)

### Run Tests

```bash
uv sync
uv run pytest
```

### Run Examples

```bash
uv sync
uv run examples/test.py
```

### Publish

Create an account on [test.pypi.org](https://test.pypi.org) and register your GitHub OIDC provider on [Publishing](https://test.pypi.org/manage/account/publishing/).
